==> haskell-x509-system-1.6.6-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-1cHi2pADEwl6DL63LN97a6
key:                  x509-system-1.6.6-1cHi2pADEwl6DL63LN97a6
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  33a084b1f585900131e56933fedd53c3
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-8.10.1/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-8.10.1/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-1cHi2pADEwl6DL63LN97a6
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-HbiwU2MlHZzGaDNGJAgIVO process-1.6.8.2
    x509-1.7.5-Gr4Toetm9yP7fHNPlcVQy3
    x509-store-1.6.7-H2jFe5pSa0O7kNURth3ayA

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-system-1.6.6-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-system
version:              1.6.6
visibility:           public
id:                   x509-system-1.6.6-K3Xc9h9yTfB7dsA6KJn14c
key:                  x509-system-1.6.6-K3Xc9h9yTfB7dsA6KJn14c
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:          System X.509 handling
category:             Data
abi:                  c8907dd4025f3c500938f9f5f7aa6784
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-8.10.1/site-local/x509-system-1.6.6
library-dirs:         /usr/lib/ghc-8.10.1/site-local/x509-system-1.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/x509-system-1.6.6
hs-libraries:         HSx509-system-1.6.6-K3Xc9h9yTfB7dsA6KJn14c
depends:
    base-4.14.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1 mtl-2.2.2
    pem-0.2.4-KhqFcBbx6DK5fDbP906pgY process-1.6.8.2
    x509-1.7.5-KLFDdOngbF2KQvFeNs3Zr2
    x509-store-1.6.7-3r0Unel5PNS2aRGGOACAhP

haddock-interfaces:   /usr/share/doc/haskell-x509-system/html/x509-system.haddock
haddock-html:         /usr/share/doc/haskell-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
